API for Kepler Orbit
=====================

Class API defined in the module.

.. currentModule:: PyAstronomy.pyasl

The solver for Kepler's Equation
---------------------------------

.. autoclass:: MarkleyKESolver
               :members:

The `KeplerEllipse` class - the orbit
--------------------------------------

.. autoclass:: KeplerEllipse
               :members:
               
The `BinaryOrbit` class
--------------------------------------

.. autoclass:: BinaryOrbit
               :members:
